package com.ruoyi.system.api;

import com.ruoyi.common.core.constant.SecurityConstants;
import com.ruoyi.common.core.constant.ServiceNameConstants;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.api.domain.SysUser;
import com.ruoyi.system.api.model.LoginUser;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author jty
 */
@FeignClient(contextId = "sysUserServiceFeign", value = ServiceNameConstants.SYSTEM_SERVICE)
@Service
public interface SysUserServiceFeign {
    /**
     * 获取当前用户信息
     */
    @GetMapping(value = "/user/info/{username}")
    R<LoginUser> info(@PathVariable("username") String username, @RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);

    /**
     * 注册用户信息
     */
    @PostMapping("/userFeign/register")
    R<Boolean> register(@RequestBody SysUser sysUser, @RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);

    /**
     * 获取用户信息
     *
     * @return 用户信息
     */
    @GetMapping("/userFeign/getInfo")
    AjaxResult getInfo(@RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);

    /**
     * 根据用户编号获取详细信息
     */
    @GetMapping(value = {"/userFeign/{userId}"})
    AjaxResult getInfo(@PathVariable(value = "userId", required = false) Long userId, @RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);

    /**
     * 修改用户
     */
    @PutMapping("/userFeign/")
    AjaxResult edit(@Validated @RequestBody SysUser user, @RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);

    /**
     * 重置密码
     */
    @PutMapping("/userFeign/resetPwd")
    AjaxResult resetPwd(@RequestBody SysUser user, @RequestHeader(value = SecurityConstants.FROM_SOURCE) String source);
}
